#lang pollen

◊(define gap-size 2)

◊(define-meta title "introduction")
◊(section-from-metas metas)

As lawyers, we know that writing is central to our work. Whether it's a sixty-page brief for the United States Supreme Court, or a two-line email tapped out in an airport terminal, our jobs require a steady flow of clear, effective written communications.

But we do more than write. We edit, we rewrite, we format, we print, we copy, we fax, we mail, we file. We take responsibility for all the steps between us and our readers. And we're liable for the consequences if we don't. So we're more than just writers—we're publishers.

In fact, we're part of the biggest publishing industry in the United States. According to the Bureau of Labor Statistics, in May 2014, the print-publishing industry (including books, newspapers, and magazines) employed 724,900 people at an average hourly wage of $38.43. Meanwhile, 1,052,900 people were employed in law-related jobs at an average hourly wage of $48.61, including 603,310 lawyers.

But those figures don't express the other dimension of our writing: how consequential it is. Some of us handle issues that involve life and death, or civil rights and oppression, or jobs and livelihoods. But regardless of the stakes, all of us are handling issues that are important to someone—our clients.

In short, our work matters.
Because our work matters, our writing matters. 
Because our writing matters, our typography matters.

I'm not here to tell you that typography is at the core of a lawyer's work. It's not. But typography can optimize that work. All writing necessarily involves typography. And good writing is part of good lawyering. So good typography is too. If you ignore typography, you're ignoring an opportunity to improve both your writing and your advocacy.

◊gap[gap-size]


This book is based on three principles.


◊numbered-list{
Good typography is part of good writing.

     
Legal documents are professionally published material and thus should be held to the same typographic standards.


Any lawyer can master the essentials of good typography.}

◊(gap gap-size)

The first chapter, ◊xref{Why typography matters}, explains what typography is and why you should care.

The next three chapters cover typographic rules. ◊xref{Type composition} covers the symbols and characters available on the keyboard. ◊xref{Text formatting} covers the appearance of characters and text, including a selection of ◊xref{font recommendations}. ◊xref{Page layout} covers the broader issues that surface when putting documents together. In each chapter, rather than grouping the rules into topics and subtopics, I’ve sequenced them roughly in order of difficulty, and grouped them into basic and advanced sets.

The last chapter, ◊xref{sample documents}, brings everything together by working through before-and-after examples of common legal documents.

◊(gap gap-size)

Use this book however you like. Some will want to learn everything in ◊xref{type composition} before moving on to ◊xref{text formatting}. Others will want to master the basic rules in each chapter before trying the advanced rules. Others will want to open the book only when a specific typographic issue arises.

Regardless of the path you take, don’t just read the rules. Practice. Find typographic problems and solve them. That’s the easiest way to get better at typography.

◊(gap gap-size)

The typographic rules in this book aren’t limited to particular software. You can apply them in just about any typesetting program.

I’ve included specific tips for five common word processors: Microsoft Word 2010 and 2013 (for Windows); Microsoft Word 2011 and 2016 (for Mac OS); and Corel WordPerfect X7 (for Windows). Tips for Word apply to all versions unless specified.

But the focus of this book is typography. It’s not intended to replace your software manual or help file. I’ve skipped technical issues that are especially basic (e.g., how to apply ◊xref{bold or italic} formatting) or especially complicated (e.g., how to implement ◊xref{paragraph and character styles}).

◊(gap gap-size)

Legal documents lie along a continuum from more typographically flexible (e.g., ◊xref{letterhead}, ◊xref{research memos}) to less (e.g., ◊xref{motions}). Not every recommendation in this book will suit every document. Use your judgment.

I sometimes illustrate typographic ideas with examples from California litigation because I’m familiar with it. But my recommendations are meant to be adaptable to any type of practice in any jurisdiction.

That said, this book is not legal advice. If what I suggest conflicts with laws or court rules in your jurisdiction, ignore me and obey the law—obviously.

◊(gap gap-size)

What qualifies me to write about typography? I have a visual-arts degree from Harvard, where I learned traditional letterpress printing and digital font design. My typographic work is in the permanent collection of the Houghton Library at Harvard. After college, I worked as a font designer for several years. I then ran a website-design studio in San Francisco. Later, I went to law school at UCLA and practiced civil litigation in Los Angeles for several years. These days, I work on a number of writing, design, and publishing projects, all centered around typography (including ◊link{http://practicaltypography.com}, a cousin of this book, aimed at a general audience).

The golden thread connecting these activities is my affection for the printed word. Technology changes, but the printed word remains irreplaceable.

◊(gap gap-size)

Typography has been a source of enjoyment for me for over 25 years. I’m grateful that I’ve had this platform to share my enthusiasm. Since the first edition of ◊em{Typography for Lawyers} was released, I’ve heard from lawyers, judges, law professors, and students all over the world about what a difference this material has made in their work. I hope that you also find it rewarding, and that it adds satisfaction—and maybe even some fun—to your practice.


◊sig{Matthew Butterick}

◊(gap (* 2 gap-size))


◊subhead{A note on the type}
In addition to writing this book, I also designed the four fonts that are used throughout — ◊xref{Equity}, ◊xref{Concourse}, ◊xref{Triplicate}, and ◊xref{Advocate} — which have emerged from my work in legal typography. These fonts can be licensed for your own projects.
